#
# Test script to run the oisst_nc2bin.py script
#
#
#  CREATED by Paolo Veglio and Eva Borbas  
#             Space Science and Engineering Center
#             University of Wisconsin-Madison

# HISTORY
#
# Version 0.5 - created on March 31, 2023 
#        - ice concentration has been filled up with GDAS over inland water
#	 - inland water mask adde as a static input
#
# Version 0.3 - created on February 7, 2023 
# 
set -e

#------------------
# SET FOR TESTING: 

scriptdir=$(realpath $(dirname $0))
indir=${scriptdir}/inputs
pydir=${scriptdir}/../dist/env/bin/
srcdir=${scriptdir}/../source/
water_fn=$srcdir/inland_water.nc

#------------------
fns=$indir/oisst*.nc

for fnin in ${fns}
do
    gran=`basename $fnin | awk -F"." '{print $2}'`
    fnout=`echo oisst.${gran}`
    gdasfn=`echo gdas1.PGrbF00.${gran:2}.00z`
    
    if [  -s $indir/$gdasfn ]; then
    
    	echo oisst_nc2bin.py $fnin $indir/$gdasfn $water_fn $fnout
    	$pydir/python $srcdir/oisst_nc2bin.py $fnin $indir/$gdasfn $water_fn $fnout
    
    else
    
    	echo 'There is no matching GDAS file for ' $fnin
    fi
    
done

exit 1
